@@ -28,6 +28,9 @@ class CSECreate(BaseModel):
   name: str
   description: str
 
+class CSEUpdate(BaseModel):
+  name: str
+  description: str
 
 class CSE(CSECreate):
   id: int
@@ -42,5 +45,5 @@ class CSEModel(Base):
   id = Column(Integer, primary_key=True, index=True)
   name = Column(String)
   description = Column(String)
-  cxes = relationship("CXModel", secondary=CSE_CX_Table)
+  cxes = relationship("CSECXModel", secondary=CSE_CX_Table)
   domains = relationship("DomainModel", secondary=CSE_Domain_Table)
